==> org-lsst-ccs-config-definition-1.6.3-sources.jar: org/lsst/ccs/config/utilities/ConfigUtils.java <==
package org.lsst.ccs.config.utilities;

import org.lsst.ccs.config.NamesAndTag;

/**
 * @author bamade
 */
// Date: 19/06/13

public class ConfigUtils {
    /**
     * gets subsystem name, configName and tag name from pathName
     * @param pathName
     * @return
     */
    public static NamesAndTag namesFromPath(String pathName) {
        //split name
        String subsystemName = "" ;
        String configName = "" ;
        String tag = "" ;
        if (isAPath(pathName) ){ // pathName is a config filename
            int indexDot =  pathName.lastIndexOf('.');
            int lastPath = pathName.lastIndexOf('/');
            String rawName = pathName.substring(lastPath + 1, indexDot);
            String[] elements = rawName.split("_");
            //falltrough !
            switch(elements.length) {
                case 3: tag = elements[2] ;
                case 2: configName = elements[1] ;
                case 1: subsystemName = elements[0] ;
            }
            return new NamesAndTag(subsystemName,configName,tag) ;
        } else { // pathName is a config name
            configName = pathName;
            return new NamesAndTag(subsystemName,configName,tag);
        }
    }
    
    /**
     * gets subsystem name, configName and tag name from the description and configuration path names
     * <BR>
     * rules:
     * <UL>
     *     <LI/>
     *     the subsystem name in both file names should be the same
     *     <LI/>
     *     if the configuration name in the description file name is not set
     *     then the configuration name is in the configuration file name.
     *     Otherwise there is a name clash if it is set in the configuration file name
     *     and it differs.
     *     <LI/>
     *     Same rule applies for the tag name.
     *
     * </UL>
     * @param descriptionPathName 
     * @param configurationPathName 
     * @throws IllegalArgumentException if subsystem, config and tag names are not consistent in description and configuration file names.
     * @return
     */
    public static NamesAndTag namesFromPaths(String descriptionPathName, String configurationPathName){
        String subsystemName, configName, tagName, configPath;
        NamesAndTag descNT = namesFromPath(descriptionPathName);
        subsystemName = descNT.getSubsystemName();
        configName = descNT.getConfigName();
        tagName = descNT.getTag();
        
        if (configurationPathName != null){
            NamesAndTag confNT = namesFromPath(configurationPathName);

            // check coherency between both NamesAndTag objects
            if (!confNT.getSubsystemName().isEmpty()){
                if (!subsystemName.equals(confNT.getSubsystemName())) {
                    throw new IllegalArgumentException(" subsystem names differs :" + subsystemName + " <> " + confNT.getSubsystemName());
                }
            }
            String newConfigName = confNT.getConfigName();
            if (configName.length() != 0 && newConfigName.length() != 0) {
                if (!configName.equals(newConfigName)) {
                    throw new IllegalArgumentException(" configuration name clash :" + configName + " <> " + newConfigName);
                }
            }
            if (newConfigName.length() != 0) {
                configName = newConfigName;
            }
            
            String newTagName = confNT.getTag();
            if (tagName.length() != 0 && newTagName.length() != 0) {
                if (!descNT.getTag().equals(newTagName)) {
                    throw new IllegalArgumentException(" tag name clash :" + tagName + " <> " + newTagName);
                }
            }
            if (newTagName.length() != 0) {
                tagName = newTagName;
            }
        }
        // Real configuration path reconstruction
        if (isAPath(configurationPathName)){
            configPath = configurationPathName;
        } else {
            configPath = baseNameFromNames(subsystemName, configName, tagName);
        }
        
        return new NamesAndTag(subsystemName, configName, tagName, configPath);
    }

    /**
     * creates a fileName from a NamesAndTag object (reverse operation of <TT>namesFromPath</TT>
     * @param namesAndTag
     * @return
     */
    public static String baseNameFromNames(NamesAndTag namesAndTag) {
        return baseNameFromNames(namesAndTag.getSubsystemName(), namesAndTag.getConfigName(), namesAndTag.getTag());
    }
    
    public static String baseNameFromNames(String subsystemName, String configName, String tagName){

        String baseName = subsystemName;
        if (configName.isEmpty()){
            if (!tagName.isEmpty())
                baseName +="__"+tagName;
        } else {
            baseName += "_" + configName;
            if (!tagName.isEmpty())
                baseName +="_"+tagName;
        }
        return baseName;
    }
    
    public static boolean isAPath(String string){
        if (string == null) return false;
        int lastDot = string.lastIndexOf(".");
        int lastPath = string.lastIndexOf("/");
        return lastDot > lastPath;
    }
}

==> org-lsst-ccs-config-definition-2.0.1-sources.jar: org/lsst/ccs/config/utilities/ConfigUtils.java <==
package org.lsst.ccs.config.utilities;

import org.lsst.ccs.config.NamesAndTag;

/**
 * @author bamade
 */
// Date: 19/06/13

public class ConfigUtils {
    /**
     * gets subsystem name, configName and tag name from pathName
     * @param pathName
     * @return
     */
    public static NamesAndTag namesFromPath(String pathName) {
        //split name
        String subsystemName = "" ;
        String configName = "" ;
        String tag = "" ;
        if (isAPath(pathName) ){ // pathName is a config filename
            int indexDot =  pathName.lastIndexOf('.');
            int lastPath = pathName.lastIndexOf('/');
            String rawName = pathName.substring(lastPath + 1, indexDot);
            String[] elements = rawName.split("_");
            //falltrough !
            if(System.getProperty("org.lsst.ccs.newfilenaming","false").equals("true")){
                switch(elements.length) {
                    case 2: configName = elements[1] ;
                    case 1: tag = elements[0] ;
                }
            } else {
                switch(elements.length) {
                    case 3: tag = elements[2] ;
                    case 2: configName = elements[1] ;
                    case 1: subsystemName = elements[0] ;
                }
            }
        } else { // pathName is a config name
            configName = pathName;
        }
        return new NamesAndTag(subsystemName,configName,tag);
    }
    
    public static NamesAndTag namesFromDescriptionPath(String pathName) {
        String subsystemName ="";
        String configName = "";
        String tag = "";
        
        if (System.getProperty("org.lsst.ccs.newfilenaming","false").equals("true")){
            tag = pathName.substring(pathName.lastIndexOf("/")+1);
        } else {
            int indexDot =  pathName.lastIndexOf('.');
            int lastPath = pathName.lastIndexOf('/');
            String rawName = pathName.substring(lastPath + 1, indexDot);
            String[] elements = rawName.split("_");
            //falltrough !
            switch(elements.length) {
                case 3: tag = elements[2] ;
                case 2: configName = elements[1] ;
                case 1: subsystemName = elements[0] ;
            }
        }
        return new NamesAndTag(subsystemName,configName,tag);
    }
    
    /**
     * gets subsystem name, configName and tag name from the description and configuration path names
     * <BR>
     * rules:
     * <UL>
     *     <LI/>
     *     the subsystem name in both file names should be the same
     *     <LI/>
     *     if the configuration name in the description file name is not set
     *     then the configuration name is in the configuration file name.
     *     Otherwise there is a name clash if it is set in the configuration file name
     *     and it differs.
     *     <LI/>
     *     Same rule applies for the tag name.
     *
     * </UL>
     * @param descriptionPathName 
     * @param configurationPathName 
     * @throws IllegalArgumentException if subsystem, config and tag names are not consistent in description and configuration file names.
     * @return
     */
    public static NamesAndTag namesFromPaths(String descriptionPathName, String configurationPathName){
        String subsystemName, configName, tagName;
        NamesAndTag descNT = namesFromDescriptionPath(descriptionPathName);
        subsystemName = descNT.getSubsystemName();
        configName = descNT.getConfigName();
        tagName = descNT.getTag();
        
        if (configurationPathName != null){
            NamesAndTag confNT = namesFromPath(configurationPathName);

            // check coherency between both NamesAndTag objects
            if (!confNT.getSubsystemName().isEmpty()){
                if (!subsystemName.equals(confNT.getSubsystemName())) {
                    throw new IllegalArgumentException(" subsystem names differs :" + subsystemName + " <> " + confNT.getSubsystemName());
                }
            }
            String newConfigName = confNT.getConfigName();
            if (configName.length() != 0 && newConfigName.length() != 0) {
                if (!configName.equals(newConfigName)) {
                    throw new IllegalArgumentException(" configuration name clash :" + configName + " <> " + newConfigName);
                }
            }
            if (newConfigName.length() != 0) {
                configName = newConfigName;
            }
            
            String newTagName = confNT.getTag();
            if (tagName.length() != 0 && newTagName.length() != 0) {
                if (!descNT.getTag().equals(newTagName)) {
                    throw new IllegalArgumentException(" tag name clash :" + tagName + " <> " + newTagName);
                }
            }
            if (newTagName.length() != 0) {
                tagName = newTagName;
            }
        
        }
        
        return new NamesAndTag(subsystemName, configName, tagName, configurationPathName);
    }

    /**
     * creates a fileName from a NamesAndTag object (reverse operation of <TT>namesFromPath</TT>
     * @param namesAndTag
     * @return
     */
    public static String baseNameFromNames(NamesAndTag namesAndTag) {
        return baseNameFromNames(namesAndTag.getSubsystemName(), namesAndTag.getConfigName(), namesAndTag.getTag());
    }
    
    public static String baseNameFromNames(String subsystemName, String configName, String tagName){
        if (System.getProperty("org.lsst.ccs.newfilenaming","false").equals("true")){
            return tagName+((configName.isEmpty())?"":("_"+configName));
        }
        else {
            String baseName = subsystemName;
            if (configName.isEmpty()){
                if (!tagName.isEmpty())
                    baseName +="__"+tagName;
            } else {
                baseName += "_" + configName;
                if (!tagName.isEmpty())
                    baseName +="_"+tagName;
            }
            return baseName;
        }
    }
    
    public static boolean isAPath(String string){
        if (string == null )return false;
        int lastDot = string.lastIndexOf(".");
        int lastPath = string.lastIndexOf("/");
        return lastDot > lastPath;
    }
}
